@@ -9,8 +9,8 @@ from .molecule import packmol
 from .dft.siesta import siesta_md 
 from .dft.SinglePointEnergy import SinglePointEnergies
 from .md.gmd import nvt_wt as gulp_nvt
-from .dft.mdtodata import MDtoData
-from .dft.prep_data import prep_data
+from .data.mdtodata import MDtoData
+from .data.prep_data import prep_data
 from .reaxfflib import read_lib
 import tensorflow as tf
 from .md.irmd import IRMD
@@ -51,7 +51,7 @@ def get_zpe(p,atom_name):
 
 class LearningMachine(object):
   ''' recursive learning machine constructed by I-ReaxFF and siesta '''
-  def __init__(self,aimd=None,initConfig='poscar.gen',
+  def __init__(self,initConfig='poscar.gen',
                direcs=None,
                ncpu=40,
                maxiter=1000,
@@ -99,6 +99,7 @@ class LearningMachine(object):
                bore={'others':0.45},
                weight={'others':2.0},
                bo_penalty=10000.0,
+               mefac=0.1,
                xcf='VDW',
                xca='DRSLL',
                basistype='DZP'):
@@ -106,11 +107,8 @@ class LearningMachine(object):
               batch: batch size
       '''
       self.initConfig   = initConfig
-      if aimd is None:
-         lab_           = initConfig.split('.')[0]
-         self.aidir     = 'aimd_' + lab_
-      else:
-         self.aidir     = aimd
+      self.label        = initConfig.split('.')[0]
+      self.aidir        = 'aimd_' + self.label
       self.accCriteria  = accCriteria # accuracy convergence criteria
       self.lossCriteria = lossCriteria    
       self.lossTole     = lossTole    
@@ -155,6 +153,7 @@ class LearningMachine(object):
       self.be_layer     = be_layer
       self.bore         = bore
       self.bom          = bom
+      self.mefac        = mefac
       self.weight       = weight
       self.bo_penalty   = bo_penalty
       self.EnergyFunction = EnergyFunction
@@ -292,9 +291,8 @@ class LearningMachine(object):
                                                      be_layer=self.be_layer,
                                                      EnergyFunction=self.EnergyFunction,
                                                      MessageFunction=self.MessageFunction,
-                                                     bore=self.bore,
-                                                     bom=self.bom,
-                                                     weight=self.weight,
+                                                     bore=self.bore, bom=self.bom,
+                                                     mefac=self.mefac,weight=self.weight,
                                                      bo_penalty=self.bo_penalty)
                 self.load_config()
                 if tIter>=self.resetAcc and tstep>=self.step:
@@ -411,7 +409,8 @@ class LearningMachine(object):
 
 
   def mlmd(self,cwd,run_dir,atoms,Tmax,Iter,learnWay):        # run classic MD to test training results
-      irmd = IRMD(atoms=atoms,time_step=self.dt_mlmd,totstep=self.md_step,Tmax=Tmax,
+      irmd = IRMD(atoms=atoms,label=self.label,
+                  time_step=self.dt_mlmd,totstep=self.md_step,Tmax=Tmax,
                   ro=self.ro,rtole=self.rtole,Iter=Iter,initT=self.T,
                   bondTole=self.bondTole,
                   CheckDE=True,dEstop=self.dEstop,
@@ -478,6 +477,7 @@ class LearningMachine(object):
                     'maxiter':self.maxiter,
                     'max_batch':self.max_batch,
                     'mpopt':self.mpopt,
+                    'mefac':self.mefac,
                     'learnWay':self.learnWay,
                     'colFrame':self.colFrame,
                     'bore':self.bore}
@@ -512,6 +512,7 @@ class LearningMachine(object):
            self.maxiter      = InPut['maxiter']
            self.max_batch    = InPut['max_batch']
            self.mpopt        = InPut['mpopt']
+           self.mefac        = InPut['mefac']
            self.learnWay     = InPut['learnWay']
            self.colFrame     = InPut['colFrame']
            self.bore         = InPut['bore']
