@@ -35,7 +35,7 @@ def getBonds(natom,r,rcut):
 
 class IRMD(object):
   ''' Intelligent Reactive Molecular Dynamics '''
-  def __init__(self,atoms=None,gen='poscar.gen',ffield='ffield.json',
+  def __init__(self,label=None,atoms=None,gen='poscar.gen',ffield='ffield.json',
                index=-1,totstep=100,vdwnn=False,nn=True,
                initT=300,Tmax=10000,time_step=0.1,
                ro=None,rtole=0.6,Iter=0,bondTole=1.3,
@@ -60,10 +60,8 @@ class IRMD(object):
       if self.atoms is None:
          self.atoms   = read(gen,index=index)
       
-      self.atoms.calc = IRFF(atoms=self.atoms,
-                             libfile=ffield,
-                             rcut=None,
-                             nn=nn,vdwnn=vdwnn)
+      self.atoms.calc = IRFF(atoms=self.atoms, mol=label,libfile=ffield,
+                             rcut=None,nn=nn,vdwnn=vdwnn)
       self.natom     = len(self.atoms)
       self.re        = self.atoms.calc.re
       self.dyn       = None
@@ -113,7 +111,12 @@ class IRMD(object):
           except:
              # for _ in i_:
              #     print('atoms pair',_)
-             print('Atoms too closed or Temperature goes too high, stop at %d.' %self.step)
+             if n>0: 
+                 print('Atoms too closed, stop at %d.' %self.step)
+             elif dE_>=self.dEstop: 
+                 print('dE = %f exceed the limit, stop at %d.' %(dE_,self.step))
+             else:
+                 print('unknown reason, stop at %d.' %self.step)
              self.dyn.max_steps = self.dyn.nsteps-1
   
       # traj = Trajectory('md.traj', 'w', self.atoms)
