@@ -22,7 +22,7 @@ def train(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence=1000
                 'ovun3':-2.0,'ovun4':-2.0,
                 'lp1':-3.0,'vdw1':-3.0},
           spec=[],
-          writelib=1000,nn=True,vdwnn=False,
+          writelib=1000,nn=True,vdwnn=False,mefac=0.1,
           bo_layer=[3,1],
           bf_layer=[9,2],
           be_layer=[3,1],
@@ -47,6 +47,7 @@ def train(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence=1000
                 nanv=nanv,
                 weight=weight,
                 bore=bore,
+                mefac=mefac,
                 convergence=convergence,
                 lossConvergence=lossConvergence) # Loss Functon can be n2,abs,mse,huber
  
@@ -91,6 +92,7 @@ def train_mpnn(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence
           EnergyFunction=3,MessageFunction=2,mpopt=3,
           bore={'others':0.45},
           bom={'others':1.0},
+          mefac=0.1,
           weight={'others':10.0},
           bo_penalty=10000.0,
           ffield = 'ffield.json'):
@@ -127,7 +129,7 @@ def train_mpnn(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence
                 bo_penalty=bo_penalty,
                 nanv=nanv,
                 bom=bom,bore=bore,
-                weight=weight,
+                weight=weight,mefac=mefac,
                 convergence=convergence,
                 lossConvergence=lossConvergence) # Loss Functon can be n2,abs,mse,huber
 
@@ -161,38 +163,12 @@ def train_mpnn(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence
     return loss,accu,accMax,p,zpe,i
 
 
-def sa(direcs=None,step=5000,batch=None,total_step=2):
-    rn = ReaxFF(libfile='ffield',
-              direcs=direcs, 
-              dft='siesta',
-              spec=['C','H','O','N'],
-              ro_scale=0.1,
-              optword='nocoul',
-              atomic=True,
-              cons=None,
-              opt=None,
-              pkl=False,
-              batch_size=batch,
-              losFunc='n2',
-              bo_penalty=100.0) # Loss Functon can be n2,abs,mse,huber
-
-
-    rn.sa(total_step=total_step,
-           step=step,astep=1000,zstep=500,
-           print_step=10,writelib=1000) 
-
-    p   = rn.p_
-    zpe = rn.zpe_
-    rn.close()
-    return loss,accu,p,zpe
-
-
 if __name__ == '__main__':
    ''' use commond like ./bp.py <t> to run it
        z:   optimize zpe 
        t:   train the whole net
    '''
    parser = argparse.ArgumentParser()
-   argh.add_commands(parser, [z,sa,train])
+   argh.add_commands(parser, [train,train_mpnn])
    argh.dispatch(parser)
 
